@@ -1,3 +1,3 @@
-.First.lib <-
+.onLoad <-
 function (lib, pkg) 
 library.dynam("bestglm", pkg, lib)
